package cn.fw.dalaran.domain.db;

import cn.fw.dalaran.domain.vo.ActivityThemeVo;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import lombok.Data;

import java.util.Arrays;
import java.util.Date;
import java.util.stream.Collectors;

/**
 * @author wmy3969
 * @version 1.0
 * @date 2022/1/11 23:46
 * @Description 活动主题实体
 */
@Data
public class ActivityTheme {
    /**
     * 主键id
     */
    @TableId(type = IdType.AUTO)
    private Long id;
    /**
     * 所属配置组id
     */
    private Long configGroupId;
    /**
     * 集团id(冗余字段)
     */
    private Long groupId;
    /**
     * 活动主题
     */
    private String theme;
    /**
     * 活动话题
     */
    private String topic;
    /**
     * 主题开始时间
     */
    private Date startTime;
    /**
     * 主题结束时间
     */
    private Date endTime;
    /**
     * 全部门店(0:否, 1:是)(冗余字段)
     */
    private Integer allShop;
    /**
     * 适用门店清单(id)(冗余字段)
     */
    private String shopIds;
    /**
     * 适用门店清单(name)(冗余字段)
     */
    private String shopNames;
    /**
     * 数据有效性过滤配置
     */
    private String validConfigJson;
    /**
     * 逻辑删除
     */
    @TableLogic(value = "0", delval = "1")
    private Integer logicDel;

    /**
     * db->vo
     *
     * @param db
     * @return 将DB传参转换成视图
     */
    public static ActivityThemeVo toVO(ActivityTheme db) {
        final ActivityThemeVo vo = new ActivityThemeVo();
        vo.setId(db.getId());
        vo.setGroupId(db.getGroupId());
        vo.setTheme(db.getTheme());
        vo.setTopic(Arrays.stream(db.getTopic().replace(",", "").substring(1).split("#"))
                .collect(Collectors.toList()));
        vo.setStartTime(db.getStartTime());
        vo.setEndTime(db.getEndTime());
        vo.setAllShop(db.getAllShop());
        if (db.getAllShop() < 1) {
            vo.setShopIds(Arrays.stream(db.getShopIds().split(","))
                    .map(Long::valueOf)
                    .collect(Collectors.toList())
            );
            vo.setShopNames(Arrays.stream(db.getShopNames().split(","))
                    .map(Object::toString)
                    .collect(Collectors.toList())
            );
        }
        return vo;
    }
}
