package cn.fw.dalaran.domain.dto;

import cn.fw.common.validator.EnumValue;
import cn.fw.dalaran.domain.enums.PlatformEnum;
import lombok.Data;
import lombok.ToString;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author kurisu
 * @date 2021-11-17 14:02
 * @description 直播池DTO
 */
@Data
@ToString(callSuper = true)
public class LivePoolDTO {
    /**
     * 账号
     */
    @NotBlank(message = "账号不能为空")
    private String account;
    /**
     * 平台类型
     */
    @EnumValue(enumClass = PlatformEnum.class, message = "无效的账号类型")
    private Integer type;
    /**
     *
     */
    private List<LiveDTO> liveList;

    @Data
    public static class LiveDTO {
        /**
         * 直播间id
         */
        private String roomNo;
        /**
         * 直播回放地址
         */
        private String playbackUrl;
        /**
         * 用户昵称
         */
        private String userNick;
        /**
         * 直播标题
         */
        private String title;
        /**
         * 直播封面
         */
        private String cover;
        /**
         * 观看人数
         */
        private Long uv;
        /**
         * 峰值观看人数
         */
        private Long uvPeak;
        /**
         * 点赞人数
         */
        private Long likeNum;
        /**
         * 评论人数
         */
        private Long commentNum;
        /**
         * 分享人数
         */
        private Long shareNum;
        /**
         * 新增粉丝数
         */
        private Long newFanNum;
        /**
         * 收礼数
         */
        private Long receiveNum;
        /**
         * 收礼金额
         */
        private BigDecimal receiveAmount;
        /**
         * 直播时长(分钟)
         */
        private Integer liveDuration;
        /**
         * 直播开始时间
         */
        private Date liveStartTime;
        /**
         * 直播结束时间
         */
        private Date liveEndTime;
        /**
         * 话题
         */
        private String tags;
    }
}
