package cn.fw.dalaran.rpc.attendance;

import cn.fw.attendance.sdk.api.AttendanceApi;
import cn.fw.attendance.sdk.api.enums.ScheduleTypeEnum;
import cn.fw.attendance.sdk.api.result.UserScheduleStatus;
import cn.fw.dalaran.common.utils.PublicUtil;
import cn.fw.dalaran.rpc.attendance.dto.StaffWorkStatusDto;
import cn.fw.data.base.domain.common.Message;
import com.alibaba.fastjson.JSON;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wmy3969
 * @version 1.0
 * @date 2022/4/13 15:26
 * @Description 考勤系统Rpc
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class AttendanceRpc {

    private final AttendanceApi attendanceApi;// 考勤系统Api

    /**
     * 获取员工指定时间上班情况
     *
     * @param userIds   员工id集合
     * @param timeStamp 指定时间
     * @return 员工指定时间上班情况
     */
    public List<StaffWorkStatusDto> getStaffWorkStatus(List<Long> userIds, Long timeStamp) {
        try {
            final Message<List<UserScheduleStatus>> result = attendanceApi.getUserStatusByDate(userIds, timeStamp);
            log.info("调用考勤系统 AttendanceApi.attendanceApi(), 入参{}, {}, 返回结果: {}", JSON.toJSONString(userIds), timeStamp, JSON.toJSONString(result));
            PublicUtil.assertTrue(result.isSuccess(), result.getResult());
            return result.getData().stream()
                    .map(item -> {
                        StaffWorkStatusDto dto = new StaffWorkStatusDto();
                        dto.setUserId(item.getUserId());
                        ScheduleTypeEnum scheduleType = item.getScheduleType();
                        dto.setWorkStatus((Objects.equals(scheduleType, ScheduleTypeEnum.WORK_MORNING) ||
                                Objects.equals(scheduleType, ScheduleTypeEnum.WORK_EVENING) ||
                                Objects.equals(scheduleType, ScheduleTypeEnum.WORK_NORMAL) ||
                                Objects.equals(scheduleType, ScheduleTypeEnum.OUTSIDE)) ? 1 : 0);
                        dto.setDetail(scheduleType.getDesc());
                        return dto;
                    })
                    .collect(Collectors.toList());
        } catch (Exception e) {
            log.error("调用考勤系统 AttendanceApi.attendanceApi(), 入参{}, {}, 异常信息为: {}", JSON.toJSONString(userIds), timeStamp, e.getMessage());
            return null;
        }
    }

}
