package cn.fw.dalaran.server.controller.web;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.dalaran.domain.param.EvlParams;
import cn.fw.dalaran.domain.vo.EvlIndexVO;
import cn.fw.dalaran.domain.vo.EvlSubIndexVO;
import cn.fw.dalaran.service.biz.EvlSettingService;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author kurisu
 * @date 2021-11-17 15:02
 * @description 评价指标设置
 */
@Slf4j
@Deprecated
@Validated
@RestController
@RequiredArgsConstructor
@Authorization(AuthType.ERP)
@RequestMapping("/web/setting")
@IgnoreAuth
public class EvlSettingController {
    private final EvlSettingService evlSettingService;

    /**
     * 修改指标
     *
     * @return
     */
    @PutMapping("/add")
    @ControllerMethod("修改评价指标设置")
    public Message<Boolean> add(@RequestBody @Valid EvlParams params) {
        return success(evlSettingService.saveEvlIndex(params.getDetails()));
    }

    /**
     * 查询评价指标列表
     *
     * @param user
     * @return
     */
    @GetMapping("/evl")
    @ControllerMethod("查询评价指标")
    public Message<List<EvlIndexVO>> list(@CurrentUser LoginAuthBean user) {
        return success(evlSettingService.list(user.getGroupId()));
    }

    /**
     * 修改评价子指标
     *
     * @return
     */
    @PutMapping("/addsub")
    @ControllerMethod("修改评价子指标设置")
    public Message<Boolean> addSub(@RequestBody @Valid EvlParams params) {
        return success(evlSettingService.saveEvlSubIndex(params.getDetails()));
    }

    /**
     * 查询评价子指标
     *
     * @param evlId
     * @return
     */
    @GetMapping("/subevl")
    @ControllerMethod("查询评价子指标")
    public Message<List<EvlSubIndexVO>> sublist(@NotNull(message = "评价指标不能为空") Long evlId) {
        return success(evlSettingService.sublist(evlId));
    }
}
